package ru.sicamp.sicamphelper.repository

import mu.KLogging
import org.jetbrains.exposed.dao.load
import org.jetbrains.exposed.dao.with
import org.jetbrains.exposed.sql.and
import org.jetbrains.exposed.sql.transactions.transaction
import org.springframework.security.core.userdetails.UsernameNotFoundException
import org.springframework.security.crypto.password.PasswordEncoder
import org.springframework.stereotype.Repository
import ru.sicamp.sicamphelper.db.entity.User
import ru.sicamp.sicamphelper.db.table.Users
import ru.sicamp.sicamphelper.model.dto.UserDto
import java.time.Duration
import java.time.LocalDateTime

@Repository
class UserRepository(
    private val passwordEncoder: PasswordEncoder
) {
    fun findUserByTgUsernameAndId(id: Long, userName: String) = transaction {
        User.find {
            (Users.tgId eq id) and
                    (Users.tgUsername eq userName)
        }.with(
            User::supervisor,
            User::group
        ).firstOrNull()
    }

    fun findUserByUsername(username: String) = transaction {
        User.find {
            Users.login eq username
        }.with(
            User::supervisor,
            User::group
        ).firstOrNull() ?: throw UsernameNotFoundException("Not found user with username $username")
    }

    fun findUserById(id: Long) = transaction {
        User.findById(id)?.load(
            User::supervisor,
            User::group
        )
    }

    fun createUser(userDto: UserDto): User = transaction {
        val now = LocalDateTime.now()
        logger.info("Creating new user at $now")
        return@transaction User.new {
            login = userDto.login
            _password = passwordEncoder.encode(userDto.password)
            role = userDto.role
            name = userDto.name
            sex = userDto.sex
            age = userDto.age
            tgId = userDto.tgId
            tgUsername = userDto.tgUsername
            locked = false
            enabled = userDto.enabled
            accountExpiration = now + userExpirationTime
            credentialsExpiration = now + credentialsExpirationTime
        }
    }

    companion object : KLogging() {
        private val userExpirationTime = Duration.ofDays(60)
        private val credentialsExpirationTime = Duration.ofDays(30)
    }
}