package ru.sicamp.sicamphelper.service

import org.springframework.stereotype.Service
import ru.sicamp.sicamphelper.db.entity.User
import ru.sicamp.sicamphelper.model.dto.UserDto
import ru.sicamp.sicamphelper.model.info.UserInfo
import ru.sicamp.sicamphelper.repository.UserRepository
import ru.sicamp.sicamphelper.util.TgUser
import ru.sicamp.sicamphelper.util.badArgument

@Service
class UserService(
    private val userRepository: UserRepository
) {
    fun findUserByTgUser(user: TgUser): User? = userRepository.findUserByTgUsernameAndId(
        id = user.id,
        userName = user.userName
    )

    fun findUserInfoByLogin(login: String) = UserInfo.from(
        userRepository.findUserByUsername(login)
    ) ?: badArgument("Not found user with login=$login")

    fun findUserInfoById(id: Long) = UserInfo.from(
        userRepository.findUserById(id)
    )

    fun createUser(userDto: UserDto): UserInfo = UserInfo.from(
        userRepository.createUser(userDto)
    ) ?: error("Failed to create user with login=${userDto.login}")

}